/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.bizFsSettleDataCheck.param;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.unis.financialSupervision.modular.businessContract.param.BusinessContractIdParam;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 清算数据提取及业务处室核验添加参数
 *
 * @author hjc
 * @date  2024/07/01 10:37
 **/
@Getter
@Setter
public class BizFsSettleDataCheckAddParam {

    /** 库区；外库depot_qh.org_info的id； */
    @ApiModelProperty(value = "库区；外库depot_qh.org_info的id；", position = 6)
    @NotNull(message = "库区id不能为空")
    private Integer orgId;

    /** 计划名称 */
    @ApiModelProperty(value = "计划名称", position = 7)
    @NotBlank(message = "计划名称不能为空")
    private String planName;

    /** 计划数量 */
    @ApiModelProperty(value = "计划数量", position = 8)
    @NotNull(message = "计划数量不能为空")
    private BigDecimal planQuantity;

    /** 实际出库数量 */
    @ApiModelProperty(value = "实际出库数量", position = 9)
    @NotNull(message = "实际出库数量不能为空")
    private BigDecimal actualOutQuantity;

    /** 实际入库数量 */
    @ApiModelProperty(value = "实际入库数量", position = 10)
    @NotNull(message = "实际入库数量不能为空")
    private BigDecimal actualInQuantity;

    /** 收集账户 */
    @ApiModelProperty(value = "收集账户", position = 11)
    @NotBlank(message = "收集账户不能为空")
    private String collectionAccount;

    /** 收集人 */
    @ApiModelProperty(value = "收集人", position = 12)
    @NotBlank(message = "收集人不能为空")
    private String collector;

    /** 收集方式 1:现金 2:移动支付 3:银行转账 4:其他 */
    @ApiModelProperty(value = "收集方式 1:现金 2:移动支付 3:银行转账 4:其他", position = 13)
    @NotNull(message = "收集方式不能为空")
    private Integer collectionMethod;

    /** 开户行名称 */
    @ApiModelProperty(value = "开户行名称", position = 14)
    @NotBlank(message = "开户行名称不能为空")
    private String bankName;

    /** 银行卡号 */
    @ApiModelProperty(value = "银行卡号", position = 15)
    @NotBlank(message = "银行卡号不能为空")
    private String bankCardNumber;

    /** 发票号 */
    @ApiModelProperty(value = "发票号", position = 16)
    private String invoiceNumber;

    /** 发票状态 0:作废 1:正常 */
    @ApiModelProperty(value = "发票状态 0:作废 1:正常", position = 17)
    @NotNull(message = "发票状态不能为空")
    private Integer invoiceStatus;

    /** 结算时间 */
    @ApiModelProperty(value = "结算时间", position = 18)
    @NotNull(message = "结算时间不能为空")
    private Date settlementTime;

 /*   *//** 贷款单号 *//*
    @ApiModelProperty(value = "贷款单号", position = 19)
    private String loanNumber;*/

    /** 贷款金额 */
    @ApiModelProperty(value = "贷款金额", position = 20)
    @NotNull(message = "贷款金额不能为空")
    private BigDecimal loanAmount;

    /** 利息单号 */
    @ApiModelProperty(value = "利息单号", position = 21)
    @NotBlank(message = "利息单号不能为空")
    private String interestNumber;

    /** 计息账户 */
    @ApiModelProperty(value = "计息账户", position = 22)
    @NotBlank(message = "计息账户不能为空")
    private String interestBearingAccount;

    /** 计息开始日 */
    @ApiModelProperty(value = "计息开始日", position = 23)
    @JsonFormat(pattern = "yyyy-MM-dd")
    @NotNull(message = "计息开始日不能为空")
    private Date interestStartDate;

    /** 计息结束日 */
    @ApiModelProperty(value = "计息结束日", position = 24)
    @JsonFormat(pattern = "yyyy-MM-dd")
    @NotNull(message = "计息结束日不能为空")
    private Date interestEndDate;

    /** 计息天数 */
    @ApiModelProperty(value = "计息天数", position = 25)
    @NotNull(message = "计息天数不能为空")
    private Integer interestDays;

    /** 计息本金 */
    @ApiModelProperty(value = "计息本金", position = 26)
    @NotNull(message = "计息本金不能为空")
    private BigDecimal principalAmount;

    /** 利率 */
    @ApiModelProperty(value = "利率", position = 27)
    @NotNull(message = "利率不能为空")
    private BigDecimal interestRate;

    /** 应计利息 */
    @ApiModelProperty(value = "应计利息", position = 28)
    @NotNull(message = "应计利息不能为空")
    private BigDecimal accruedInterest;

    /** 实计利息 */
    @ApiModelProperty(value = "实计利息", position = 29)
    @NotNull(message = "实计利息不能为空")
    private BigDecimal actualInterest;

    /** 罚息率 */
    @ApiModelProperty(value = "罚息率", position = 30)
    @NotNull(message = "罚息率不能为空")
    private BigDecimal penaltyRate;

    /** 应计罚息 */
    @ApiModelProperty(value = "应计罚息", position = 31)
    @NotNull(message = "应计罚息不能为空")
    private BigDecimal accruedPenaltyInterest;

    /** 实计罚息 */
    @ApiModelProperty(value = "实计罚息", position = 32)
    @NotNull(message = "实计罚息不能为空")
    private BigDecimal actualPenaltyInterest;

    /** 逾期天数 */
    @ApiModelProperty(value = "逾期天数", position = 33)
    @NotNull(message = "逾期天数不能为空")
    private Integer overdueDays;

    /** 币种 */
    @ApiModelProperty(value = "币种", position = 34)
    @NotBlank(message = "币种不能为空")
    private String currency;

    /** 状态 0：未核验；1：已核验； */
    @ApiModelProperty(value = "状态 0：未核验；1：已核验；", position = 35)
    @NotNull(message = "状态是否核验不能为空")
    private Integer checkStatus;

    /** 状态 0：未清算；1：已清算； */
    @ApiModelProperty(value = "状态 0：未清算；1：已清算；", position = 36)
    @NotNull(message = "状态是否清算不能为空")
    private Integer clearStatus;


    /** 合同id */
    @ApiModelProperty(value = "合同id", position = 37)
    private List<BusinessContractIdParam> businessContractIdList;
}
