/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.bizFsSettleDataCheck.service;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import com.unis.basic.info.modular.orgInfo.entity.OrgInfo;
import com.unis.financialSupervision.modular.bizFsSettleDataCheck.entity.BizFsSettleDataCheck;
import com.unis.financialSupervision.modular.bizFsSettleDataCheck.param.*;
import com.unis.financialSupervision.modular.bizFsSettleDataCheck.vo.BizFsSettleDataCheckDetailVO;
import com.unis.financialSupervision.modular.bizFsSettleDataCheck.vo.BizFsSettleDataCheckPageVO;
import com.unis.financialSupervision.modular.bizFsSettleDataCheck.vo.GetBusinessContractDetailVO;
import com.unis.financialSupervision.modular.businessContract.entity.BusinessContract;

import java.util.List;

/**
 * 清算数据提取及业务处室核验Service接口
 *
 * @author hjc
 * @date  2024/07/01 10:37
 **/
public interface BizFsSettleDataCheckService extends IService<BizFsSettleDataCheck> {

    /**
     * 获取清算数据提取及业务处室核验分页
     *
     * @author hjc
     * @date  2024/07/01 10:37
     */
    Page<BizFsSettleDataCheckPageVO> page(BizFsSettleDataCheckPageParam bizFsSettleDataCheckPageParam);

    /**
     * 添加清算数据提取及业务处室核验
     *
     * @author hjc
     * @date  2024/07/01 10:37
     */
    void add(BizFsSettleDataCheckAddParam bizFsSettleDataCheckAddParam);

    /**
     * 编辑清算数据提取及业务处室核验
     *
     * @author hjc
     * @date  2024/07/01 10:37
     */
    void edit(BizFsSettleDataCheckEditParam bizFsSettleDataCheckEditParam);

    /**
     * 删除清算数据提取及业务处室核验
     *
     * @author hjc
     * @date  2024/07/01 10:37
     */
    void delete(List<BizFsSettleDataCheckIdParam> bizFsSettleDataCheckIdParamList);

    /**
     * 获取清算数据提取及业务处室核验详情
     *
     * @author hjc
     * @date  2024/07/01 10:37
     */
    BizFsSettleDataCheckDetailVO detail(BizFsSettleDataCheckIdParam bizFsSettleDataCheckIdParam);

    /**
     * 获取清算数据提取及业务处室核验详情
     *
     * @author hjc
     * @date  2024/07/01 10:37
     **/
    BizFsSettleDataCheck queryEntity(String id);

    /**
     * 清算数据提取及业务处室核验-核验
     *
     * @author hjc
     * @date 2024/07/01 10:37
     */
    void verification(VerificationParam param);
    /**
     * 获取库区名称
     *
     * @author hjc
     * @date 2024/07/01 10:37
     */
    List<OrgInfo> getOrgInfo();

    /**
     * 获取合同编号
     *
     * @author hjc
     * @date 2024/07/01 10:37
     */
    List<BusinessContract> getBusinessContract();

    /**
     * 通过合同id获取品种，数量，单价，价款
     *
     * @author hjc
     * @date 2024/07/01 10:37
     */
    GetBusinessContractDetailVO getBusinessContractDetail(BizFsSettleDataCheckIdParam param);

    /**
     * 清算数据生成-分页
     *
     * @author hjc
     * @date 2024/07/01 10:37
     */
    Page<BizFsSettleDataCheckPageVO> liquidationPage(liquidationPageParam pageParam);

    /**
     * 清算核定及确认-分页
     *
     * @author hjc
     * @date 2024/07/01 10:37
     */
    Page<BizFsSettleDataCheckPageVO> checkLiquidationPage(CheckLiquidationPageParam pageParam);

    /**
     * 清算核定及确认-一键清算
     *
     * @author hjc
     * @date 2024/07/01 10:37
     */
    void checkClearStatus(VerificationParam param);

    JSONObject getDetailJSON(BizFsSettleDataCheckIdParam bizFsSettleDataCheckIdParam);
}
