/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.bizFsSettleDataCheckItem.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.financialSupervision.modular.bizFsSettleDataCheckItem.entity.BizFsSettleDataCheckItem;
import com.unis.financialSupervision.modular.bizFsSettleDataCheckItem.param.BizFsSettleDataCheckItemAddParam;
import com.unis.financialSupervision.modular.bizFsSettleDataCheckItem.param.BizFsSettleDataCheckItemEditParam;
import com.unis.financialSupervision.modular.bizFsSettleDataCheckItem.param.BizFsSettleDataCheckItemIdParam;
import com.unis.financialSupervision.modular.bizFsSettleDataCheckItem.param.BizFsSettleDataCheckItemPageParam;
import com.unis.financialSupervision.modular.bizFsSettleDataCheckItem.service.BizFsSettleDataCheckItemService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 清算数据提取及业务处室核验-合同控制器
 *
 * @author hjc
 * @date  2024/07/01 10:39
 */
@Api(tags = "清算数据提取及业务处室核验-合同控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizFsSettleDataCheckItemController {

    @Resource
    private BizFsSettleDataCheckItemService bizFsSettleDataCheckItemService;

    /**
     * 获取清算数据提取及业务处室核验-合同分页
     *
     * @author hjc
     * @date  2024/07/01 10:39
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取清算数据提取及业务处室核验-合同分页")
    //@SaCheckPermission("/financialSupervision/bizFsSettleDataCheckItem/page")
    @GetMapping("/financialSupervision/bizFsSettleDataCheckItem/page")
    public CommonResult<Page<BizFsSettleDataCheckItem>> page(BizFsSettleDataCheckItemPageParam bizFsSettleDataCheckItemPageParam) {
        return CommonResult.data(bizFsSettleDataCheckItemService.page(bizFsSettleDataCheckItemPageParam));
    }

    /**
     * 添加清算数据提取及业务处室核验-合同
     *
     * @author hjc
     * @date  2024/07/01 10:39
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加清算数据提取及业务处室核验-合同")
    @CommonLog("添加清算数据提取及业务处室核验-合同")
    //@SaCheckPermission("/financialSupervision/bizFsSettleDataCheckItem/add")
    @PostMapping("/financialSupervision/bizFsSettleDataCheckItem/add")
    public CommonResult<String> add(@RequestBody @Valid BizFsSettleDataCheckItemAddParam bizFsSettleDataCheckItemAddParam) {
        bizFsSettleDataCheckItemService.add(bizFsSettleDataCheckItemAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑清算数据提取及业务处室核验-合同
     *
     * @author hjc
     * @date  2024/07/01 10:39
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑清算数据提取及业务处室核验-合同")
    @CommonLog("编辑清算数据提取及业务处室核验-合同")
    //@SaCheckPermission("/financialSupervision/bizFsSettleDataCheckItem/edit")
    @PostMapping("/financialSupervision/bizFsSettleDataCheckItem/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizFsSettleDataCheckItemEditParam bizFsSettleDataCheckItemEditParam) {
        bizFsSettleDataCheckItemService.edit(bizFsSettleDataCheckItemEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除清算数据提取及业务处室核验-合同
     *
     * @author hjc
     * @date  2024/07/01 10:39
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除清算数据提取及业务处室核验-合同")
    @CommonLog("删除清算数据提取及业务处室核验-合同")
    //@SaCheckPermission("/financialSupervision/bizFsSettleDataCheckItem/delete")
    @PostMapping("/financialSupervision/bizFsSettleDataCheckItem/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizFsSettleDataCheckItemIdParam> bizFsSettleDataCheckItemIdParamList) {
        bizFsSettleDataCheckItemService.delete(bizFsSettleDataCheckItemIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取清算数据提取及业务处室核验-合同详情
     *
     * @author hjc
     * @date  2024/07/01 10:39
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取清算数据提取及业务处室核验-合同详情")
    //@SaCheckPermission("/financialSupervision/bizFsSettleDataCheckItem/detail")
    @GetMapping("/financialSupervision/bizFsSettleDataCheckItem/detail")
    public CommonResult<BizFsSettleDataCheckItem> detail(@Valid BizFsSettleDataCheckItemIdParam bizFsSettleDataCheckItemIdParam) {
        return CommonResult.data(bizFsSettleDataCheckItemService.detail(bizFsSettleDataCheckItemIdParam));
    }
}
