/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.bizFsSettleDataCheckItem.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.financialSupervision.modular.bizFsSettleDataCheckItem.entity.BizFsSettleDataCheckItem;
import com.unis.financialSupervision.modular.bizFsSettleDataCheckItem.mapper.BizFsSettleDataCheckItemMapper;
import com.unis.financialSupervision.modular.bizFsSettleDataCheckItem.param.BizFsSettleDataCheckItemAddParam;
import com.unis.financialSupervision.modular.bizFsSettleDataCheckItem.param.BizFsSettleDataCheckItemEditParam;
import com.unis.financialSupervision.modular.bizFsSettleDataCheckItem.param.BizFsSettleDataCheckItemIdParam;
import com.unis.financialSupervision.modular.bizFsSettleDataCheckItem.param.BizFsSettleDataCheckItemPageParam;
import com.unis.financialSupervision.modular.bizFsSettleDataCheckItem.service.BizFsSettleDataCheckItemService;

import java.util.List;

/**
 * 清算数据提取及业务处室核验-合同Service接口实现类
 *
 * @author hjc
 * @date  2024/07/01 10:39
 **/
@Service
public class BizFsSettleDataCheckItemServiceImpl extends ServiceImpl<BizFsSettleDataCheckItemMapper, BizFsSettleDataCheckItem> implements BizFsSettleDataCheckItemService {

    @Override
    public Page<BizFsSettleDataCheckItem> page(BizFsSettleDataCheckItemPageParam bizFsSettleDataCheckItemPageParam) {
        QueryWrapper<BizFsSettleDataCheckItem> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(bizFsSettleDataCheckItemPageParam.getSortField(), bizFsSettleDataCheckItemPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizFsSettleDataCheckItemPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizFsSettleDataCheckItemPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizFsSettleDataCheckItemPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizFsSettleDataCheckItem::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizFsSettleDataCheckItemAddParam bizFsSettleDataCheckItemAddParam) {
        BizFsSettleDataCheckItem bizFsSettleDataCheckItem = BeanUtil.toBean(bizFsSettleDataCheckItemAddParam, BizFsSettleDataCheckItem.class);
        this.save(bizFsSettleDataCheckItem);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizFsSettleDataCheckItemEditParam bizFsSettleDataCheckItemEditParam) {
        BizFsSettleDataCheckItem bizFsSettleDataCheckItem = this.queryEntity(bizFsSettleDataCheckItemEditParam.getId());
        BeanUtil.copyProperties(bizFsSettleDataCheckItemEditParam, bizFsSettleDataCheckItem);
        this.updateById(bizFsSettleDataCheckItem);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizFsSettleDataCheckItemIdParam> bizFsSettleDataCheckItemIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizFsSettleDataCheckItemIdParamList, BizFsSettleDataCheckItemIdParam::getId));
    }

    @Override
    public BizFsSettleDataCheckItem detail(BizFsSettleDataCheckItemIdParam bizFsSettleDataCheckItemIdParam) {
        return this.queryEntity(bizFsSettleDataCheckItemIdParam.getId());
    }

    @Override
    public BizFsSettleDataCheckItem queryEntity(String id) {
        BizFsSettleDataCheckItem bizFsSettleDataCheckItem = this.getById(id);
        if(ObjectUtil.isEmpty(bizFsSettleDataCheckItem)) {
            throw new CommonException("清算数据提取及业务处室核验-合同不存在，id值为：{}", id);
        }
        return bizFsSettleDataCheckItem;
    }
}
