/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.businessContract.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.financialSupervision.modular.businessContract.entity.BusinessContract;
import com.unis.financialSupervision.modular.businessContract.param.BusinessContractAddParam;
import com.unis.financialSupervision.modular.businessContract.param.BusinessContractEditParam;
import com.unis.financialSupervision.modular.businessContract.param.BusinessContractIdParam;
import com.unis.financialSupervision.modular.businessContract.param.BusinessContractPageParam;
import com.unis.financialSupervision.modular.businessContract.service.BusinessContractService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 合同信息控制器
 *
 * @author hjc
 * @date  2024/07/01 15:01
 */
@Api(tags = "合同信息控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BusinessContractController {

    @Resource
    private BusinessContractService businessContractService;

    /**
     * 获取合同信息分页
     *
     * @author hjc
     * @date  2024/07/01 15:01
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取合同信息分页")
    @SaCheckPermission("/financialSupervision/businessContract/page")
    @GetMapping("/financialSupervision/businessContract/page")
    public CommonResult<Page<BusinessContract>> page(BusinessContractPageParam businessContractPageParam) {
        return CommonResult.data(businessContractService.page(businessContractPageParam));
    }

    /**
     * 添加合同信息
     *
     * @author hjc
     * @date  2024/07/01 15:01
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加合同信息")
    @CommonLog("添加合同信息")
    @SaCheckPermission("/financialSupervision/businessContract/add")
    @PostMapping("/financialSupervision/businessContract/add")
    public CommonResult<String> add(@RequestBody @Valid BusinessContractAddParam businessContractAddParam) {
        businessContractService.add(businessContractAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑合同信息
     *
     * @author hjc
     * @date  2024/07/01 15:01
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑合同信息")
    @CommonLog("编辑合同信息")
    @SaCheckPermission("/financialSupervision/businessContract/edit")
    @PostMapping("/financialSupervision/businessContract/edit")
    public CommonResult<String> edit(@RequestBody @Valid BusinessContractEditParam businessContractEditParam) {
        businessContractService.edit(businessContractEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除合同信息
     *
     * @author hjc
     * @date  2024/07/01 15:01
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除合同信息")
    @CommonLog("删除合同信息")
    @SaCheckPermission("/financialSupervision/businessContract/delete")
    @PostMapping("/financialSupervision/businessContract/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BusinessContractIdParam> businessContractIdParamList) {
        businessContractService.delete(businessContractIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取合同信息详情
     *
     * @author hjc
     * @date  2024/07/01 15:01
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取合同信息详情")
    @SaCheckPermission("/financialSupervision/businessContract/detail")
    @GetMapping("/financialSupervision/businessContract/detail")
    public CommonResult<BusinessContract> detail(@Valid BusinessContractIdParam businessContractIdParam) {
        return CommonResult.data(businessContractService.detail(businessContractIdParam));
    }
}
