/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.businessContract.param;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 合同信息编辑参数
 *
 * @author hjc
 * @date  2024/07/01 15:01
 **/
@Getter
@Setter
public class BusinessContractEditParam {

    /** 主键 */
    @ApiModelProperty(value = "主键", required = true, position = 1)
    @NotNull(message = "id不能为空")
    private Integer id;

    /** 合同编号 */
    @ApiModelProperty(value = "合同编号", position = 2)
    private String contractNumber;

    /** 计划id；biz_rp_issuance的ID； */
    @ApiModelProperty(value = "计划id；biz_rp_issuance的ID；", position = 3)
    private Integer planBid;

    /** 合同名称 */
    @ApiModelProperty(value = "合同名称", position = 4)
    private String contractTitle;

    /** 合同类型；busbasic_enum的ID； */
    @ApiModelProperty(value = "合同类型；busbasic_enum的ID；", position = 5)
    private Integer contractType;

    /** 合同签订时间，竞拍日期 */
    @ApiModelProperty(value = "合同签订时间，竞拍日期", position = 6)
    private Date signingTime;

    /** 签订地点 */
    @ApiModelProperty(value = "签订地点", position = 7)
    private String qddd;

    /** 合同总金额(元) */
    @ApiModelProperty(value = "合同总金额(元)", position = 8)
    private String moneyQuantity;

    /** 履约保证金 */
    @ApiModelProperty(value = "履约保证金", position = 9)
    private String lybzj;

    /** 客户id；business_customer的ID； */
    @ApiModelProperty(value = "客户id；business_customer的ID；", position = 10)
    private Integer customerBid;

    /** 合同粮食数量(吨)；约定购销粮食数量； */
    @ApiModelProperty(value = "合同粮食数量(吨)；约定购销粮食数量；", position = 11)
    private BigDecimal grainQuantity;

    /** 中转方式；busbasic_enum的ID；废弃 */
    @ApiModelProperty(value = "中转方式；busbasic_enum的ID；废弃", position = 12)
    private String customerId;

    /** 客户编号；废弃； */
    @ApiModelProperty(value = "客户编号；废弃；", position = 13)
    private String customerNumber;

    /** 合同客户名称；废弃； */
    @ApiModelProperty(value = "合同客户名称；废弃；", position = 14)
    private String customerName;

    /** 合同签订人；废弃； */
    @ApiModelProperty(value = "合同签订人；废弃；", position = 15)
    private String signingMan;

    /** 合同生效日期；废弃； */
    @ApiModelProperty(value = "合同生效日期；废弃；", position = 16)
    private Date enableDate;

    /** 履约数量 */
    @ApiModelProperty(value = "履约数量", position = 17)
    private BigDecimal performanceQuantity;

    /** 履约率 */
    @ApiModelProperty(value = "履约率", position = 18)
    private BigDecimal performanceRate;

    /** 结算与合同一致性 0：不一致；1：一致； */
    @ApiModelProperty(value = "结算与合同一致性 0：不一致；1：一致；", position = 19)
    private Integer settleContractUniformity;

    /** 结算与合同不一致性原因 */
    @ApiModelProperty(value = "结算与合同不一致性原因", position = 20)
    private String settleContractUniformityReason;

    /** 签约完成时间 */
    @ApiModelProperty(value = "签约完成时间", position = 21)
    private Date signCompleTime;

    /** 采购单位 */
    @ApiModelProperty(value = "采购单位", position = 22)
    private String purchaseUnit;

    /** 合同截止日期 */
    @ApiModelProperty(value = "合同截止日期", position = 23)
    private Date disableDate;

    /** 原合同编号；废弃； */
    @ApiModelProperty(value = "原合同编号；废弃；", position = 24)
    private String originalContract;

    /** 原合同id */
    @ApiModelProperty(value = "原合同id", position = 25)
    private Integer originalContractBid;

    /** 起始合同id */
    @ApiModelProperty(value = "起始合同id", position = 26)
    private Integer rootContractBid;

    /** 运输方式；废弃； */
    @ApiModelProperty(value = "运输方式；废弃；", position = 27)
    private Integer shippingType;

    /** 支付方式；废弃； */
    @ApiModelProperty(value = "支付方式；废弃；", position = 28)
    private Integer contractPayType;

    /** 已完成数量 */
    @ApiModelProperty(value = "已完成数量", position = 29)
    private String finishedQuantity;

    /** 已完成数量金额 */
    @ApiModelProperty(value = "已完成数量金额", position = 30)
    private String moneyOfFinishedQuantity;

    /** 合同备注；废弃； */
    @ApiModelProperty(value = "合同备注；废弃；", position = 31)
    private String remark;

    /** 客户种粮面积(亩)；废弃； */
    @ApiModelProperty(value = "客户种粮面积(亩)；废弃；", position = 32)
    private String plantAcreage;

    /** 计划编号，废弃 */
    @ApiModelProperty(value = "计划编号，废弃", position = 33)
    private String planNumber;

    /** 客户联系方式； */
    @ApiModelProperty(value = "客户联系方式；", position = 34)
    private String mobile;

    /** 开户行名称； */
    @ApiModelProperty(value = "开户行名称；", position = 35)
    private String bankName;

    /** 银行账户名称； */
    @ApiModelProperty(value = "银行账户名称；", position = 36)
    private String accountName;

    /** 开户账号； */
    @ApiModelProperty(value = "开户账号；", position = 37)
    private String accountNumber;

    /** 违约责任； */
    @ApiModelProperty(value = "违约责任；", position = 38)
    private String breachLiability;

    /** 解除条件； */
    @ApiModelProperty(value = "解除条件；", position = 39)
    private String dissolutionConditions;

    /** 客户-证件号 */
    @ApiModelProperty(value = "客户-证件号", position = 40)
    private String identification;

    /** 客户签约人 */
    @ApiModelProperty(value = "客户签约人", position = 41)
    private String khqyr;

    /** 本方开户行 */
    @ApiModelProperty(value = "本方开户行", position = 42)
    private String bfkhh;

    /** 本方账号 */
    @ApiModelProperty(value = "本方账号", position = 43)
    private String bfzh;

    /** 争议解决方式； */
    @ApiModelProperty(value = "争议解决方式；", position = 44)
    private String disputeSettlementMethod;

    /** 合同的变更记录标志； */
    @ApiModelProperty(value = "合同的变更记录标志；", position = 45)
    private String changeRecordFlag;

    /** 合同变更原因 */
    @ApiModelProperty(value = "合同变更原因", position = 46)
    private String changeReason;

    /** 变更时间 */
    @ApiModelProperty(value = "变更时间", position = 47)
    private Date changeTime;

    /** 变更内容 */
    @ApiModelProperty(value = "变更内容", position = 48)
    private String changeContent;

    /** 是否在被变更中(0否；1是；2变更成功) */
    @ApiModelProperty(value = "是否在被变更中(0否；1是；2变更成功)", position = 49)
    private String changing;

    /** 审批状态（0待提交，1审批中，2同意，3驳回，4拒绝） */
    @ApiModelProperty(value = "审批状态（0待提交，1审批中，2同意，3驳回，4拒绝）", position = 50)
    private String auditState;

    /** 流程实例id */
    @ApiModelProperty(value = "流程实例id", position = 51)
    private String processInstanceId;

    /** 流程定义id */
    @ApiModelProperty(value = "流程定义id", position = 52)
    private String processDefinitionId;

    /** 审批完成时间 */
    @ApiModelProperty(value = "审批完成时间", position = 53)
    private Date agreeTime;

    /** 合同创建人(数据传输使用）；废弃； */
    @ApiModelProperty(value = "合同创建人(数据传输使用）；废弃；", position = 54)
    private String createMan;

    /** 创建人 */
    @ApiModelProperty(value = "创建人", position = 55)
    private String creater;

    /** 创建部门 */
    @ApiModelProperty(value = "创建部门", position = 57)
    private String createUnit;

    /** 暂停或终止原因 */
    @ApiModelProperty(value = "暂停或终止原因", position = 58)
    private String createDepot;

    /** 单位id；org_info的ID； */
    @ApiModelProperty(value = "单位id；org_info的ID；", position = 60)
    private Integer orgId;

    /** 启用状态 0 : 未执行,1 : 执行中,2 : 执行完毕,3 : 终止,4 : 暂停 */
    @ApiModelProperty(value = "启用状态 0 : 未执行,1 : 执行中,2 : 执行完毕,3 : 终止,4 : 暂停", position = 61)
    private Integer inApplication;

    /** 创建人id */
    @ApiModelProperty(value = "创建人id", position = 62)
    private Integer createrId;

    /** 更新时间 */
    @ApiModelProperty(value = "更新时间", position = 63)
    private Date updatetime;

    /** 附件 */
    @ApiModelProperty(value = "附件", position = 64)
    private String attachment;

}
