/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.businessContract.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.financialSupervision.modular.businessContract.entity.BusinessContract;
import com.unis.financialSupervision.modular.businessContract.mapper.BusinessContractMapper;
import com.unis.financialSupervision.modular.businessContract.param.BusinessContractAddParam;
import com.unis.financialSupervision.modular.businessContract.param.BusinessContractEditParam;
import com.unis.financialSupervision.modular.businessContract.param.BusinessContractIdParam;
import com.unis.financialSupervision.modular.businessContract.param.BusinessContractPageParam;
import com.unis.financialSupervision.modular.businessContract.service.BusinessContractService;

import java.util.List;

/**
 * 合同信息Service接口实现类
 *
 * @author hjc
 * @date  2024/07/01 15:01
 **/
@Service
public class BusinessContractServiceImpl extends ServiceImpl<BusinessContractMapper, BusinessContract> implements BusinessContractService {

    @Override
    public Page<BusinessContract> page(BusinessContractPageParam businessContractPageParam) {
        QueryWrapper<BusinessContract> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(businessContractPageParam.getSortField(), businessContractPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(businessContractPageParam.getSortOrder());
            queryWrapper.orderBy(true, businessContractPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(businessContractPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BusinessContract::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BusinessContractAddParam businessContractAddParam) {
        BusinessContract businessContract = BeanUtil.toBean(businessContractAddParam, BusinessContract.class);
        this.save(businessContract);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BusinessContractEditParam businessContractEditParam) {
        BusinessContract businessContract = this.queryEntity(businessContractEditParam.getId());
        BeanUtil.copyProperties(businessContractEditParam, businessContract);
        this.updateById(businessContract);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BusinessContractIdParam> businessContractIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(businessContractIdParamList, BusinessContractIdParam::getId));
    }

    @Override
    public BusinessContract detail(BusinessContractIdParam businessContractIdParam) {
        return this.queryEntity(businessContractIdParam.getId());
    }

    @Override
    public BusinessContract queryEntity(Integer id) {
        BusinessContract businessContract = this.getById(id);
        if(ObjectUtil.isEmpty(businessContract)) {
            throw new CommonException("合同信息不存在，id值为：{}", id);
        }
        return businessContract;
    }
}
