/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.businessStoreWareDetail.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.financialSupervision.modular.businessStoreWareDetail.entity.BusinessStoreWareDetail;
import com.unis.financialSupervision.modular.businessStoreWareDetail.param.BusinessStoreWareDetailAddParam;
import com.unis.financialSupervision.modular.businessStoreWareDetail.param.BusinessStoreWareDetailEditParam;
import com.unis.financialSupervision.modular.businessStoreWareDetail.param.BusinessStoreWareDetailIdParam;
import com.unis.financialSupervision.modular.businessStoreWareDetail.param.BusinessStoreWareDetailPageParam;
import com.unis.financialSupervision.modular.businessStoreWareDetail.service.BusinessStoreWareDetailService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 合同、通知单明细表控制器
 *
 * @author hjc
 * @date  2024/07/01 15:04
 */
@Api(tags = "合同、通知单明细表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BusinessStoreWareDetailController {

    @Resource
    private BusinessStoreWareDetailService businessStoreWareDetailService;

    /**
     * 获取合同、通知单明细表分页
     *
     * @author hjc
     * @date  2024/07/01 15:04
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取合同、通知单明细表分页")
    @SaCheckPermission("/financialSupervision/businessStoreWareDetail/page")
    @GetMapping("/financialSupervision/businessStoreWareDetail/page")
    public CommonResult<Page<BusinessStoreWareDetail>> page(BusinessStoreWareDetailPageParam businessStoreWareDetailPageParam) {
        return CommonResult.data(businessStoreWareDetailService.page(businessStoreWareDetailPageParam));
    }

    /**
     * 添加合同、通知单明细表
     *
     * @author hjc
     * @date  2024/07/01 15:04
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加合同、通知单明细表")
    @CommonLog("添加合同、通知单明细表")
    @SaCheckPermission("/financialSupervision/businessStoreWareDetail/add")
    @PostMapping("/financialSupervision/businessStoreWareDetail/add")
    public CommonResult<String> add(@RequestBody @Valid BusinessStoreWareDetailAddParam businessStoreWareDetailAddParam) {
        businessStoreWareDetailService.add(businessStoreWareDetailAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑合同、通知单明细表
     *
     * @author hjc
     * @date  2024/07/01 15:04
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑合同、通知单明细表")
    @CommonLog("编辑合同、通知单明细表")
    @SaCheckPermission("/financialSupervision/businessStoreWareDetail/edit")
    @PostMapping("/financialSupervision/businessStoreWareDetail/edit")
    public CommonResult<String> edit(@RequestBody @Valid BusinessStoreWareDetailEditParam businessStoreWareDetailEditParam) {
        businessStoreWareDetailService.edit(businessStoreWareDetailEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除合同、通知单明细表
     *
     * @author hjc
     * @date  2024/07/01 15:04
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除合同、通知单明细表")
    @CommonLog("删除合同、通知单明细表")
    @SaCheckPermission("/financialSupervision/businessStoreWareDetail/delete")
    @PostMapping("/financialSupervision/businessStoreWareDetail/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BusinessStoreWareDetailIdParam> businessStoreWareDetailIdParamList) {
        businessStoreWareDetailService.delete(businessStoreWareDetailIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取合同、通知单明细表详情
     *
     * @author hjc
     * @date  2024/07/01 15:04
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取合同、通知单明细表详情")
    @SaCheckPermission("/financialSupervision/businessStoreWareDetail/detail")
    @GetMapping("/financialSupervision/businessStoreWareDetail/detail")
    public CommonResult<BusinessStoreWareDetail> detail(@Valid BusinessStoreWareDetailIdParam businessStoreWareDetailIdParam) {
        return CommonResult.data(businessStoreWareDetailService.detail(businessStoreWareDetailIdParam));
    }
}
