/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.businessStoreWareDetail.param;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 合同、通知单明细表添加参数
 *
 * @author hjc
 * @date  2024/07/01 15:04
 **/
@Getter
@Setter
public class BusinessStoreWareDetailAddParam {

    /** 主表id；type=contract时，business_contract的id;
type=notice时，business_delivery_storage_notice的ID； */
    @ApiModelProperty(value = "主表id；type=contract时，business_contract的id;type=notice时，business_delivery_storage_notice的ID；", position = 2)
    private Integer zid;

    /** 类型  contract(合同) notice(通知单) */
    @ApiModelProperty(value = "类型  contract(合同) notice(通知单)", position = 3)
    private String type;

    /** basic_storehouse的id；仓房id */
    @ApiModelProperty(value = "basic_storehouse的id；仓房id", position = 4)
    private Integer houseId;

    /** 仓房名称 */
    @ApiModelProperty(value = "仓房名称", position = 5)
    private String houseName;

    /** basic_warehouse的id；货位id; */
    @ApiModelProperty(value = "basic_warehouse的id；货位id;", position = 6)
    private Integer warehouseId;

    /** 货位名称 */
    @ApiModelProperty(value = "货位名称", position = 7)
    private String warehouseName;

    /** 承储库点；org_info的ID；废弃； */
    @ApiModelProperty(value = "承储库点；org_info的ID；废弃；", position = 9)
    private Integer orgId;

    /** 粮油品种；basic_enum的id； */
    @ApiModelProperty(value = "粮油品种；basic_enum的id；", position = 10)
    private Integer grainKind;

    /** 明细品种；basic_enum的id；废弃； */
    @ApiModelProperty(value = "明细品种；basic_enum的id；废弃；", position = 11)
    private Integer grainDetailKind;

    /** 粮油等级；basic_enum的id； */
    @ApiModelProperty(value = "粮油等级；basic_enum的id；", position = 12)
    private Integer grainGrade;

    /** 粮油性质；basic_enum的id； */
    @ApiModelProperty(value = "粮油性质；basic_enum的id；", position = 13)
    private Integer grainAttribute;

    /** 收获年度 */
    @ApiModelProperty(value = "收获年度", position = 14)
    private Integer grainAnnual;

    /** 粮油产地 */
    @ApiModelProperty(value = "粮油产地", position = 15)
    private Integer grainProducingArea;

    /** 轮入单价 */
    @ApiModelProperty(value = "轮入单价", position = 16)
    private String inPrice;

    /** 数量 */
    @ApiModelProperty(value = "数量", position = 17)
    private String inCount;

    /** 总价 */
    @ApiModelProperty(value = "总价", position = 18)
    private String inDetailTotalPrice;

    /** 入库时间 */
    @ApiModelProperty(value = "入库时间", position = 19)
    private Date inputTime;

    /** 轮换计划（0：轮入，1：轮出）；废弃； */
    @ApiModelProperty(value = "轮换计划（0：轮入，1：轮出）；废弃；", position = 20)
    private Integer state;

    /** 生产年份 */
    @ApiModelProperty(value = "生产年份", position = 21)
    private Integer productiveYear;

    /** 剩余数量 */
    @ApiModelProperty(value = "剩余数量", position = 22)
    private String remainingNumber;

    /** 更新时间 */
    @ApiModelProperty(value = "更新时间", position = 23)
    private Date updatetime;

    /** 轮出价格 */
    @ApiModelProperty(value = "轮出价格", position = 24)
    private String outPrice;

    /** 轮出数量 */
    @ApiModelProperty(value = "轮出数量", position = 25)
    private String outCount;

    /** 轮出总价 */
    @ApiModelProperty(value = "轮出总价", position = 26)
    private String outDetailTotalPrice;

    /** 轮出剩余数量 */
    @ApiModelProperty(value = "轮出剩余数量", position = 27)
    private String outRemainingNumber;

    /** 入库类型:1包干轮换2调节储备轮换3竞价采购；废弃； */
    @ApiModelProperty(value = "入库类型:1包干轮换2调节储备轮换3竞价采购；废弃；", position = 28)
    private Integer incomingType;

    /** 接收的通知单id；废弃； */
    @ApiModelProperty(value = "接收的通知单id；废弃；", position = 29)
    private Integer jstzdId;

    /** 合同编号；废弃； */
    @ApiModelProperty(value = "合同编号；废弃；", position = 30)
    private String htbh;

    /** 完成数量；出入库使用； */
    @ApiModelProperty(value = "完成数量；出入库使用；", position = 31)
    private BigDecimal completeQuantity;

    /** 剩余数量；出入库使用； */
    @ApiModelProperty(value = "剩余数量；出入库使用；", position = 32)
    private BigDecimal remainQuantity;

}
