/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.businessStoreWareDetail.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.financialSupervision.modular.businessStoreWareDetail.entity.BusinessStoreWareDetail;
import com.unis.financialSupervision.modular.businessStoreWareDetail.mapper.BusinessStoreWareDetailMapper;
import com.unis.financialSupervision.modular.businessStoreWareDetail.param.BusinessStoreWareDetailAddParam;
import com.unis.financialSupervision.modular.businessStoreWareDetail.param.BusinessStoreWareDetailEditParam;
import com.unis.financialSupervision.modular.businessStoreWareDetail.param.BusinessStoreWareDetailIdParam;
import com.unis.financialSupervision.modular.businessStoreWareDetail.param.BusinessStoreWareDetailPageParam;
import com.unis.financialSupervision.modular.businessStoreWareDetail.service.BusinessStoreWareDetailService;

import java.util.List;

/**
 * 合同、通知单明细表Service接口实现类
 *
 * @author hjc
 * @date  2024/07/01 15:04
 **/
@Service
public class BusinessStoreWareDetailServiceImpl extends ServiceImpl<BusinessStoreWareDetailMapper, BusinessStoreWareDetail> implements BusinessStoreWareDetailService {

    @Override
    public Page<BusinessStoreWareDetail> page(BusinessStoreWareDetailPageParam businessStoreWareDetailPageParam) {
        QueryWrapper<BusinessStoreWareDetail> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(businessStoreWareDetailPageParam.getSortField(), businessStoreWareDetailPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(businessStoreWareDetailPageParam.getSortOrder());
            queryWrapper.orderBy(true, businessStoreWareDetailPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(businessStoreWareDetailPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BusinessStoreWareDetail::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BusinessStoreWareDetailAddParam businessStoreWareDetailAddParam) {
        BusinessStoreWareDetail businessStoreWareDetail = BeanUtil.toBean(businessStoreWareDetailAddParam, BusinessStoreWareDetail.class);
        this.save(businessStoreWareDetail);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BusinessStoreWareDetailEditParam businessStoreWareDetailEditParam) {
        BusinessStoreWareDetail businessStoreWareDetail = this.queryEntity(businessStoreWareDetailEditParam.getId());
        BeanUtil.copyProperties(businessStoreWareDetailEditParam, businessStoreWareDetail);
        this.updateById(businessStoreWareDetail);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BusinessStoreWareDetailIdParam> businessStoreWareDetailIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(businessStoreWareDetailIdParamList, BusinessStoreWareDetailIdParam::getId));
    }

    @Override
    public BusinessStoreWareDetail detail(BusinessStoreWareDetailIdParam businessStoreWareDetailIdParam) {
        return this.queryEntity(businessStoreWareDetailIdParam.getId());
    }

    @Override
    public BusinessStoreWareDetail queryEntity(Integer id) {
        BusinessStoreWareDetail businessStoreWareDetail = this.getById(id);
        if(ObjectUtil.isEmpty(businessStoreWareDetail)) {
            throw new CommonException("合同、通知单明细表不存在，id值为：{}", id);
        }
        return businessStoreWareDetail;
    }
}
