/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.fsinterestsubsidysettle.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.financialSupervision.modular.fsinterestsubsidysettle.entity.FsInterestSubsidySettle;
import com.unis.financialSupervision.modular.fsinterestsubsidysettle.mapper.FsInterestSubsidySettleMapper;
import com.unis.financialSupervision.modular.fsinterestsubsidysettle.param.FsInterestSubsidySettleAddParam;
import com.unis.financialSupervision.modular.fsinterestsubsidysettle.param.FsInterestSubsidySettleEditParam;
import com.unis.financialSupervision.modular.fsinterestsubsidysettle.param.FsInterestSubsidySettleIdParam;
import com.unis.financialSupervision.modular.fsinterestsubsidysettle.param.FsInterestSubsidySettlePageParam;
import com.unis.financialSupervision.modular.fsinterestsubsidysettle.service.FsInterestSubsidySettleService;

import java.util.List;

/**
 * 财务监管-省级储备粮清算管理-利息补贴清算表Service接口实现类
 *
 * @author ZeroLiYi
 * @date  2024/06/28 17:51
 **/
@Service
public class FsInterestSubsidySettleServiceImpl extends ServiceImpl<FsInterestSubsidySettleMapper, FsInterestSubsidySettle> implements FsInterestSubsidySettleService {

    @Override
    public Page<FsInterestSubsidySettle> page(FsInterestSubsidySettlePageParam fsInterestSubsidySettlePageParam) {
        QueryWrapper<FsInterestSubsidySettle> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(fsInterestSubsidySettlePageParam.getSortField(), fsInterestSubsidySettlePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(fsInterestSubsidySettlePageParam.getSortOrder());
            queryWrapper.orderBy(true, fsInterestSubsidySettlePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(fsInterestSubsidySettlePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(FsInterestSubsidySettle::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(FsInterestSubsidySettleAddParam fsInterestSubsidySettleAddParam) {
        FsInterestSubsidySettle fsInterestSubsidySettle = BeanUtil.toBean(fsInterestSubsidySettleAddParam, FsInterestSubsidySettle.class);
        this.save(fsInterestSubsidySettle);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(FsInterestSubsidySettleEditParam fsInterestSubsidySettleEditParam) {
        FsInterestSubsidySettle fsInterestSubsidySettle = this.queryEntity(fsInterestSubsidySettleEditParam.getId());
        BeanUtil.copyProperties(fsInterestSubsidySettleEditParam, fsInterestSubsidySettle);
        this.updateById(fsInterestSubsidySettle);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<FsInterestSubsidySettleIdParam> fsInterestSubsidySettleIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(fsInterestSubsidySettleIdParamList, FsInterestSubsidySettleIdParam::getId));
    }

    @Override
    public FsInterestSubsidySettle detail(FsInterestSubsidySettleIdParam fsInterestSubsidySettleIdParam) {
        return this.queryEntity(fsInterestSubsidySettleIdParam.getId());
    }

    @Override
    public FsInterestSubsidySettle queryEntity(String id) {
        FsInterestSubsidySettle fsInterestSubsidySettle = this.getById(id);
        if(ObjectUtil.isEmpty(fsInterestSubsidySettle)) {
            throw new CommonException("财务监管-省级储备粮清算管理-利息补贴清算表不存在，id值为：{}", id);
        }
        return fsInterestSubsidySettle;
    }
}
