/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.fsrpcostinterestsettle.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.financialSupervision.modular.fsrpcostinterestsettle.entity.FsRpCostInterestSettle;
import com.unis.financialSupervision.modular.fsrpcostinterestsettle.param.FsRpCostInterestSettleAddParam;
import com.unis.financialSupervision.modular.fsrpcostinterestsettle.param.FsRpCostInterestSettleEditParam;
import com.unis.financialSupervision.modular.fsrpcostinterestsettle.param.FsRpCostInterestSettleIdParam;
import com.unis.financialSupervision.modular.fsrpcostinterestsettle.param.FsRpCostInterestSettlePageParam;
import com.unis.financialSupervision.modular.fsrpcostinterestsettle.service.FsRpCostInterestSettleService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 财务监管-省级储备粮清算管理-轮换费用利息补贴清算表控制器
 *
 * @author ZeroLiYi
 * @date  2024/06/28 10:57
 */
@Api(tags = "财务监管-省级储备粮清算管理-轮换费用利息补贴清算表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class FsRpCostInterestSettleController {

    @Resource
    private FsRpCostInterestSettleService fsRpCostInterestSettleService;

    /**
     * 获取财务监管-省级储备粮清算管理-轮换费用利息补贴清算表分页
     *
     * @author ZeroLiYi
     * @date  2024/06/28 10:57
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取财务监管-省级储备粮清算管理-轮换费用利息补贴清算表")
    @GetMapping("/financialSupervision/fsrpcostinterestsettle/page")
    public CommonResult<List<FsRpCostInterestSettle>> page(FsRpCostInterestSettlePageParam fsRpCostInterestSettlePageParam) {
        return CommonResult.data(fsRpCostInterestSettleService.page(fsRpCostInterestSettlePageParam));
    }

    /**
     * 添加财务监管-省级储备粮清算管理-轮换费用利息补贴清算表
     *
     * @author ZeroLiYi
     * @date  2024/06/28 10:57
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加财务监管-省级储备粮清算管理-轮换费用利息补贴清算表")
    @CommonLog("添加财务监管-省级储备粮清算管理-轮换费用利息补贴清算表")
    @SaCheckPermission("/financialSupervision/fsrpcostinterestsettle/add")
    @PostMapping("/financialSupervision/fsrpcostinterestsettle/add")
    public CommonResult<String> add(@RequestBody @Valid List<FsRpCostInterestSettleAddParam> fsRpCostInterestSettleAddParamList) {
        fsRpCostInterestSettleService.add(fsRpCostInterestSettleAddParamList);
        return CommonResult.ok();
    }

    /**
     * 编辑财务监管-省级储备粮清算管理-轮换费用利息补贴清算表
     *
     * @author ZeroLiYi
     * @date  2024/06/28 10:57
     */
//    @ApiOperationSupport(order = 3)
//    @ApiOperation("编辑财务监管-省级储备粮清算管理-轮换费用利息补贴清算表")
//    @CommonLog("编辑财务监管-省级储备粮清算管理-轮换费用利息补贴清算表")
//    @SaCheckPermission("/financialSupervision/fsrpcostinterestsettle/edit")
//    @PostMapping("/financialSupervision/fsrpcostinterestsettle/edit")
//    public CommonResult<String> edit(@RequestBody @Valid FsRpCostInterestSettleEditParam fsRpCostInterestSettleEditParam) {
//        fsRpCostInterestSettleService.edit(fsRpCostInterestSettleEditParam);
//        return CommonResult.ok();
//    }

    /**
     * 删除财务监管-省级储备粮清算管理-轮换费用利息补贴清算表
     *
     * @author ZeroLiYi
     * @date  2024/06/28 10:57
     */
//    @ApiOperationSupport(order = 4)
//    @ApiOperation("删除财务监管-省级储备粮清算管理-轮换费用利息补贴清算表")
//    @CommonLog("删除财务监管-省级储备粮清算管理-轮换费用利息补贴清算表")
//    @SaCheckPermission("/financialSupervision/fsrpcostinterestsettle/delete")
//    @PostMapping("/financialSupervision/fsrpcostinterestsettle/delete")
//    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
//                                                   CommonValidList<FsRpCostInterestSettleIdParam> fsRpCostInterestSettleIdParamList) {
//        fsRpCostInterestSettleService.delete(fsRpCostInterestSettleIdParamList);
//        return CommonResult.ok();
//    }

    /**
     * 获取财务监管-省级储备粮清算管理-轮换费用利息补贴清算表详情
     *
     * @author ZeroLiYi
     * @date  2024/06/28 10:57
     */
//    @ApiOperationSupport(order = 5)
//    @ApiOperation("获取财务监管-省级储备粮清算管理-轮换费用利息补贴清算表详情")
//    @SaCheckPermission("/financialSupervision/fsrpcostinterestsettle/detail")
//    @GetMapping("/financialSupervision/fsrpcostinterestsettle/detail")
//    public CommonResult<FsRpCostInterestSettle> detail(@Valid FsRpCostInterestSettleIdParam fsRpCostInterestSettleIdParam) {
//        return CommonResult.data(fsRpCostInterestSettleService.detail(fsRpCostInterestSettleIdParam));
//    }
}
