/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.priceApproval.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.financialSupervision.modular.priceApproval.entity.DataCPZ;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.financialSupervision.modular.priceApproval.entity.PriceApproval;
import com.unis.financialSupervision.modular.priceApproval.param.PriceApprovalEditParam;
import com.unis.financialSupervision.modular.priceApproval.param.PriceApprovalIdParam;
import com.unis.financialSupervision.modular.priceApproval.param.PriceApprovalPageParam;
import com.unis.financialSupervision.modular.priceApproval.service.PriceApprovalService;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.List;

/**
 * 方案价格核定控制器
 *
 * @author QSHan
 * @date  2024/07/08 15:08
 */
@Api(tags = "入库价格核定控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class PriceApprovalController {
    @Resource
    private PriceApprovalService priceApprovalService;

    /**
     * 获取方案价格核定分页
     *
     * @author QSHan
     * @date  2024/07/08 15:08
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取入库价格核定分页")
//    @SaCheckPermission("/financialSupervision/priceApproval/page")
    @GetMapping("/financialSupervision/priceApproval/page")
    public CommonResult<Page<PriceApproval>> page(PriceApprovalPageParam priceApprovalPageParam) {
        return CommonResult.data(priceApprovalService.page(priceApprovalPageParam));
    }

    /**
     * 添加方案价格核定
     *
     * @author QSHan
     * @date  2024/07/08 15:08
     */
    /*@ApiOperationSupport(order = 2)
    @ApiOperation("添加入库价格核定")
    @CommonLog("添加入库价格核定")
//    @SaCheckPermission("/financialSupervision/priceApproval/add")
    @PostMapping("/financialSupervision/priceApproval/add")
    public CommonResult<String> add(@RequestBody @Valid PriceApprovalAddParam priceApprovalAddParam) {
        priceApprovalService.add(priceApprovalAddParam);
        return CommonResult.ok();
    }*/

    /**
     * 编辑方案价格核定
     *
     * @author QSHan
     * @date  2024/07/08 15:08
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑入库价格核定")
    @CommonLog("编辑入库价格核定")
//    @SaCheckPermission("/financialSupervision/priceApproval/edit")
    @PostMapping("/financialSupervision/priceApproval/edit")
    public CommonResult<String> edit(@RequestBody @Valid PriceApprovalEditParam priceApprovalEditParam) {
        priceApprovalService.edit(priceApprovalEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除方案价格核定
     *
     * @author QSHan
     * @date  2024/07/08 15:08
     */
    /*@ApiOperationSupport(order = 4)
    @ApiOperation("删除入库价格核定")
    @CommonLog("删除入库价格核定")
//    @SaCheckPermission("/financialSupervision/priceApproval/delete")
    @PostMapping("/financialSupervision/priceApproval/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<PriceApprovalIdParam> priceApprovalIdParamList) {
        priceApprovalService.delete(priceApprovalIdParamList);
        return CommonResult.ok();
    }*/

    /**
     * 获取方案价格核定详情
     *
     * @author QSHan
     * @date  2024/07/08 15:08
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取入库价格核定详情")
//    @SaCheckPermission("/financialSupervision/priceApproval/detail")
    @GetMapping("/financialSupervision/priceApproval/detail")
    public CommonResult<PriceApproval> detail(@Valid PriceApprovalIdParam priceApprovalIdParam) {
        return CommonResult.data(priceApprovalService.detail(priceApprovalIdParam));
    }

    @GetMapping("/financialSupervision/priceApproval/getApprovalThreeRKMX/{orgId}")
    @ApiOperation(value = "三账一致性-入库明细", notes = "入库明细")
    public CommonResult<List<DataCPZ>> getApprovalThreeRKMX(@PathVariable("orgId") Integer orgId) {
        return CommonResult.data(priceApprovalService.getApprovalThreeRKMX(orgId));
    }
}
