/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.priceApprovalInspection.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.financialSupervision.modular.priceApprovalInspection.entity.PriceApprovalInspection;
import com.unis.financialSupervision.modular.priceApprovalInspection.mapper.PriceApprovalInspectionMapper;
import com.unis.financialSupervision.modular.priceApprovalInspection.param.PriceApprovalInspectionAddParam;
import com.unis.financialSupervision.modular.priceApprovalInspection.param.PriceApprovalInspectionEditParam;
import com.unis.financialSupervision.modular.priceApprovalInspection.param.PriceApprovalInspectionIdParam;
import com.unis.financialSupervision.modular.priceApprovalInspection.param.PriceApprovalInspectionPageParam;
import com.unis.financialSupervision.modular.priceApprovalInspection.service.PriceApprovalInspectionService;

import java.util.List;

/**
 * 方案价格核定-质检信息Service接口实现类
 *
 * @author QSHan
 * @date  2024/07/08 15:12
 **/
@Service
public class PriceApprovalInspectionServiceImpl extends ServiceImpl<PriceApprovalInspectionMapper, PriceApprovalInspection> implements PriceApprovalInspectionService {

    @Override
    public Page<PriceApprovalInspection> page(PriceApprovalInspectionPageParam priceApprovalInspectionPageParam) {
        QueryWrapper<PriceApprovalInspection> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(priceApprovalInspectionPageParam.getSortField(), priceApprovalInspectionPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(priceApprovalInspectionPageParam.getSortOrder());
            queryWrapper.orderBy(true, priceApprovalInspectionPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(priceApprovalInspectionPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(PriceApprovalInspection::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(PriceApprovalInspectionAddParam priceApprovalInspectionAddParam) {
        PriceApprovalInspection priceApprovalInspection = BeanUtil.toBean(priceApprovalInspectionAddParam, PriceApprovalInspection.class);
        this.save(priceApprovalInspection);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(PriceApprovalInspectionEditParam priceApprovalInspectionEditParam) {
        PriceApprovalInspection priceApprovalInspection = this.queryEntity(priceApprovalInspectionEditParam.getId());
        BeanUtil.copyProperties(priceApprovalInspectionEditParam, priceApprovalInspection);
        this.updateById(priceApprovalInspection);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<PriceApprovalInspectionIdParam> priceApprovalInspectionIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(priceApprovalInspectionIdParamList, PriceApprovalInspectionIdParam::getId));
    }

    @Override
    public PriceApprovalInspection detail(PriceApprovalInspectionIdParam priceApprovalInspectionIdParam) {
        return this.queryEntity(priceApprovalInspectionIdParam.getId());
    }

    @Override
    public PriceApprovalInspection queryEntity(Integer id) {
        PriceApprovalInspection priceApprovalInspection = this.getById(id);
        if(ObjectUtil.isEmpty(priceApprovalInspection)) {
            throw new CommonException("方案价格核定-质检信息不存在，id值为：{}", id);
        }
        return priceApprovalInspection;
    }
}
