/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.financialSupervision.modular.priceApprovalSettle.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.financialSupervision.modular.priceApprovalSettle.entity.PriceApprovalSettle;
import com.unis.financialSupervision.modular.priceApprovalSettle.mapper.PriceApprovalSettleMapper;
import com.unis.financialSupervision.modular.priceApprovalSettle.param.PriceApprovalSettleAddParam;
import com.unis.financialSupervision.modular.priceApprovalSettle.param.PriceApprovalSettleEditParam;
import com.unis.financialSupervision.modular.priceApprovalSettle.param.PriceApprovalSettleIdParam;
import com.unis.financialSupervision.modular.priceApprovalSettle.param.PriceApprovalSettlePageParam;
import com.unis.financialSupervision.modular.priceApprovalSettle.service.PriceApprovalSettleService;

import java.util.List;

/**
 * 方案价格核定-结算信息Service接口实现类
 *
 * @author QSHan
 * @date  2024/07/08 15:20
 **/
@Service
public class PriceApprovalSettleServiceImpl extends ServiceImpl<PriceApprovalSettleMapper, PriceApprovalSettle> implements PriceApprovalSettleService {

    @Override
    public Page<PriceApprovalSettle> page(PriceApprovalSettlePageParam priceApprovalSettlePageParam) {
        QueryWrapper<PriceApprovalSettle> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(priceApprovalSettlePageParam.getSortField(), priceApprovalSettlePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(priceApprovalSettlePageParam.getSortOrder());
            queryWrapper.orderBy(true, priceApprovalSettlePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(priceApprovalSettlePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(PriceApprovalSettle::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(PriceApprovalSettleAddParam priceApprovalSettleAddParam) {
        PriceApprovalSettle priceApprovalSettle = BeanUtil.toBean(priceApprovalSettleAddParam, PriceApprovalSettle.class);
        this.save(priceApprovalSettle);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(PriceApprovalSettleEditParam priceApprovalSettleEditParam) {
        PriceApprovalSettle priceApprovalSettle = this.queryEntity(priceApprovalSettleEditParam.getId());
        BeanUtil.copyProperties(priceApprovalSettleEditParam, priceApprovalSettle);
        this.updateById(priceApprovalSettle);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<PriceApprovalSettleIdParam> priceApprovalSettleIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(priceApprovalSettleIdParamList, PriceApprovalSettleIdParam::getId));
    }

    @Override
    public PriceApprovalSettle detail(PriceApprovalSettleIdParam priceApprovalSettleIdParam) {
        return this.queryEntity(priceApprovalSettleIdParam.getId());
    }

    @Override
    public PriceApprovalSettle queryEntity(Integer id) {
        PriceApprovalSettle priceApprovalSettle = this.getById(id);
        if(ObjectUtil.isEmpty(priceApprovalSettle)) {
            throw new CommonException("方案价格核定-结算信息不存在，id值为：{}", id);
        }
        return priceApprovalSettle;
    }
}
