/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.rotationPlan.info.modular.rpIssuance.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.rotationPlan.info.modular.businessrpreport.entity.BusinessRpOutbound;
import com.unis.rotationPlan.info.modular.businessrpreport.enums.BusinessRpItem;
import com.unis.rotationPlan.info.modular.rpIssuance.entity.vo.RpIssuanceVO;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.rotationPlan.info.modular.rpIssuance.entity.RpIssuance;
import com.unis.rotationPlan.info.modular.rpIssuance.mapper.RpIssuanceMapper;
import com.unis.rotationPlan.info.modular.rpIssuance.param.RpIssuanceAddParam;
import com.unis.rotationPlan.info.modular.rpIssuance.param.RpIssuanceEditParam;
import com.unis.rotationPlan.info.modular.rpIssuance.param.RpIssuanceIdParam;
import com.unis.rotationPlan.info.modular.rpIssuance.param.RpIssuancePageParam;
import com.unis.rotationPlan.info.modular.rpIssuance.service.RpIssuanceService;

import javax.annotation.Resource;
import java.util.*;

import static com.unis.rotationPlan.info.modular.rpIssuance.util.OutboundDataOrganizer.organizeOutboundData;

/**
 * 轮换计划-轮换下发Service接口实现类
 *
 * @author TS
 * @date  2024/05/08 18:02
 **/
@Service
public class RpIssuanceServiceImpl extends ServiceImpl<RpIssuanceMapper, RpIssuance> implements RpIssuanceService {
//    @Resource
//    private  BusinessRpOutbound

    @Resource
    private RpIssuanceMapper rpIssuanceMapper;


    /**
     * 获取轮换计划-轮换下发分页
     * @param rpIssuancePageParam
     * @return
     */
    @Override
    public List<RpIssuanceVO> page(RpIssuancePageParam rpIssuancePageParam) {
       List<RpIssuanceVO> rpIssuanceVOList = rpIssuanceMapper.selectRIPage(rpIssuancePageParam);
    return rpIssuanceVOList;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(RpIssuanceAddParam rpIssuanceAddParam) {
        // 初始化当前的rpReportId和RpIssuance实体
        Integer currentRpReportId = null;
        RpIssuance currentRpIssuance = null;

        List<BusinessRpOutbound> outboundList = rpIssuanceAddParam.getBusinessRpOutboundList();
        for (BusinessRpOutbound out : outboundList) {
            // 根据出库表的id修改 计划数量
            rpIssuanceMapper.updateForOut(out.getPlanQuantity(), out.getId());

            if (!Objects.equals(out.getRpReportId(), currentRpReportId)) {
                // 如果不同，则创建新的RpIssuance实体
                if (currentRpIssuance != null) {
                    try {
                        this.save(currentRpIssuance);
                    } catch (Exception e) {
                        // 处理保存实体时可能出现的异常
                        System.err.println("Failed to save RpIssuance entity: " + e.getMessage());
                    }
                }
                currentRpReportId = out.getRpReportId();
                currentRpIssuance = initializeNewRpIssuance(rpIssuanceAddParam, out);
            }
        }

        // 不要忘记保存最后一个RpIssuance实体（如果有的话）
        if (currentRpIssuance != null) {
            try {
                this.save(currentRpIssuance);
            } catch (Exception e) {
                // 处理保存实体时可能出现的异常
                System.err.println("Failed to save RpIssuance entity: " + e.getMessage());
            }
        }
    }

    private RpIssuance initializeNewRpIssuance(RpIssuanceAddParam param, BusinessRpOutbound outbound) {
        RpIssuance rpIssuance = new RpIssuance();
        rpIssuance.setCreateTime(new Date());
        rpIssuance.setUpdateTime(new Date());
        // 检查outbound不为null
        if (outbound != null) {
            rpIssuance.setRpReportId(outbound.getRpReportId());
        }

// 检查param不为null
        if (param != null) {
            if(param.getPlanName()!=null){
                rpIssuance.setPlanName(param.getPlanName());
            }
            if(param.getPlanNumber()!=null){
                rpIssuance.setPlanNumber(param.getPlanNumber());
            }
            if(param.getPlanYear()!=null){
                rpIssuance.setPlanYear(param.getPlanYear());
            }
            if(param.getStartDate()!=null){
                rpIssuance.setStartDate(param.getStartDate());
            }
            if(param.getEndDate()!=null){
                rpIssuance.setEndDate(param.getEndDate());
            }
            if(param.getAttachment()!=null){
                rpIssuance.setAttachment(param.getAttachment());
            }
        }

        rpIssuance.setIssuanceDate(new Date());
        return rpIssuance;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(RpIssuanceEditParam rpIssuanceEditParam) {
        RpIssuance rpIssuance = this.queryEntity(rpIssuanceEditParam.getId());
        BeanUtil.copyProperties(rpIssuanceEditParam, rpIssuance);
        this.updateById(rpIssuance);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<RpIssuanceIdParam> rpIssuanceIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(rpIssuanceIdParamList, RpIssuanceIdParam::getId));
    }

    @Override
    public RpIssuanceVO detail(RpIssuanceIdParam rpIssuanceIdParam) {
        RpIssuanceVO rpIssuanceVO = new RpIssuanceVO();
        List<BusinessRpOutbound> outboundList =new ArrayList<>();
        if(rpIssuanceIdParam!=null){
            if(rpIssuanceIdParam.getRpReportId()==null){
                rpIssuanceVO= rpIssuanceMapper.getRpIssuanceByadd(rpIssuanceIdParam);
                outboundList =rpIssuanceMapper.getNewOutIssuanceByrpReportId(rpIssuanceIdParam);
            }else{
                rpIssuanceVO= rpIssuanceMapper.getRpIssuanceByrpReportId(rpIssuanceIdParam);
                outboundList =rpIssuanceMapper.getOutIssuanceByrpReportId(rpIssuanceIdParam);
            }

        }
        if(rpIssuanceVO==null){
            rpIssuanceVO =  new RpIssuanceVO();
        }

        // 调用organizeOutboundData方法并处理结果
        List<Map<String, Object>> organizedResult = organizeOutboundData(outboundList);
        if(organizedResult!=null){
            rpIssuanceVO.setComplexDataList(organizedResult);
        }


        return rpIssuanceVO;
    }

    @Override
    public RpIssuance queryEntity(String id) {
        RpIssuance rpIssuance = this.getById(id);
        if(ObjectUtil.isEmpty(rpIssuance)) {
            throw new CommonException("轮换计划-轮换下发不存在，id值为：{}", id);
        }
        return rpIssuance;
    }
}
